// ShaderModule class implementation
#include "pch.h"

#include "ShaderModule.h"
#include "util.h"

namespace nf::client::render {
    ShaderModule::ShaderModule(const VkDevice& device, const std::string& shaderBinary)
        : m_device(device)
        , m_shaderModule()
    {
        VkShaderModuleCreateInfo shaderModuleCI = { VK_STRUCTURE_TYPE_SHADER_MODULE_CREATE_INFO };
        shaderModuleCI.codeSize = shaderBinary.size();
        shaderModuleCI.pCode = reinterpret_cast<const uint32_t*>(shaderBinary.data());

        if (vkCreateShaderModule(device, &shaderModuleCI, nullptr, &m_shaderModule) != VK_SUCCESS)
            NFError("Could not create shader module.");
    }

    VkShaderModule& ShaderModule::getHandle() {
        return m_shaderModule;
    }

    ShaderModule::~ShaderModule() {
        vkDestroyShaderModule(m_device, m_shaderModule, nullptr);
    }
}
